# bullets [![NPM version](https://img.shields.io/npm/v/bullets.svg)](https://www.npmjs.com/package/bullets) [![Build Status](https://img.shields.io/travis/jonschlinkert/bullets.svg)](https://travis-ci.org/jonschlinkert/bullets)

> Generate a plain-text and markdown formatted lists or tables of contents, with proper indentation, bullets, numbers, letters, roman numerals or custom characters.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm i bullets --save
```

## Usage

```js
var bullets = require('bullets');
```

## Examples

**Roman numerals**

```js
var list = [
  {text: 'Item a...', lvl: 0}, 
  {text: 'Item b...', lvl: 1}, 
  {text: 'Item c...', lvl: 2},
  {text: 'Item d...', lvl: 2},
  {text: 'Item e...', lvl: 2},
];

// let's generate 100 numerals, in case our list grows.
var actual = bullets(list, {chars: '1..100'}, function (ch) {
  return romanize(ch) + '.';
});
```

Results in:

```
I. Item a...
  II. Item b...
    III. Item c...
    III. Item d...
    III. Item e...
```

## API

### [bullets](index.js#L56)

Pass an array of list-item objects to generate a formatted list or table of contents. Uses [list-item](https://github.com/jonschlinkert/list-item) for generating the actual items.

Note that `lvl` or `level` may be passed as the property name in the
following examples.

**Params**

* `list` **{Array}**: Array of item objects with `text` and `lvl` properties
* `list.text` **{String}**: The text for the list item.
* `list.lvl` **{Number}**: The level of the list item to be used for indenting the list.
* `opts` **{Object}**: Options to pass to [list-item](https://github.com/jonschlinkert/list-item).
* `fn` **{Function}**: pass a function to modify the bullet for an item as it's generated.

**Example**

```js
var list = [
  {text: 'This is item 1', lvl: 0},
  {text: 'This is item 2', lvl: 0},
  {text: 'This is item 3', lvl: 0},
  {text: 'This is sub-item A', lvl: 2},
  {text: 'This is sub-item B', lvl: 2},
  {text: 'This is sub-item C', lvl: 2},
];
bullets([{text: 'This is a list item', lvl: 0}]);

// Results in
// '- This is item 1'
// '- This is item 2'
// '- This is item 3'
// '  * This is sub-item A'
// '  * This is sub-item B'
// '  * This is sub-item C'
```

## Related projects

[list-item](https://www.npmjs.com/package/list-item): Generate a single formatted list item, allowing you to easily generate lists with proper indentation,… [more](https://www.npmjs.com/package/list-item) | [homepage](https://github.com/jonschlinkert/list-item)

## Running tests

Install dev dependencies:

```sh
$ npm i -d && npm test
```

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/bullets/issues/new).

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016 [Jon Schlinkert](https://github.com/jonschlinkert)
Released under the MIT license.

***

_This file was generated by [verb](https://github.com/verbose/verb) on January 19, 2016._