# to-list [![NPM version](https://img.shields.io/npm/v/to-list.svg)](https://www.npmjs.com/package/to-list) [![Build Status](https://img.shields.io/travis/jonschlinkert/to-list.svg)](https://travis-ci.org/jonschlinkert/to-list)

> Parse a string into a list object with text and level properties.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm i to-list --save
```

## Usage

```js
var toList = require('to-list');
```

## API

The following list is assumed to be the source string in all examples:

```
- This is item 1
- This is item 2
- This is item 3
  * This is sub-item A
  * This is sub-item B
  * This is sub-item C
```

**Example**

```js
var list = toList(str);
//=> list[0].level === 0
//=> list[3].level === 2
```

**Results in**

The list is parsed into any array that looks something like:

```js
[ { text: 'This is item 1',
    lead: [ '- ', index: 0, input: '- This is item 1' ],
    level: 0 },
  { text: 'This is item 2',
    lead: [ '- ', index: 0, input: '- This is item 2' ],
    level: 0 },
  { text: 'This is item 3',
    lead: [ '- ', index: 0, input: '- This is item 3' ],
    level: 0 },
  { text: 'This is sub-item A',
    lead: [ '  * ', index: 0, input: '  * This is sub-item A' ],
    level: 2 },
  { text: 'This is sub-item B',
    lead: [ '  * ', index: 0, input: '  * This is sub-item B' ],
    level: 2 },
  { text: 'This is sub-item C',
    lead: [ '  * ', index: 0, input: '  * This is sub-item C' ],
    level: 2 } ]
```

### Item function

Pass a function as the second argument to customize each item object as it's created:

```js
var list = toList(str, function(item) {
  item.level = item.level / 2;
  return item;
});

//=> list[0].level === 0
//=> list[3].level === 1
```

## Related projects

* [bullets](https://www.npmjs.com/package/bullets): Generate a plain-text and markdown formatted lists or tables of contents, with proper indentation, bullets,… [more](https://www.npmjs.com/package/bullets) | [homepage](https://github.com/jonschlinkert/bullets)
* [list-item](https://www.npmjs.com/package/list-item): Generate a single formatted list item, allowing you to easily generate lists with proper indentation,… [more](https://www.npmjs.com/package/list-item) | [homepage](https://github.com/jonschlinkert/list-item)

## Running tests

Install dev dependencies:

```sh
$ npm i -d && npm test
```

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/to-list/issues/new).

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016 [Jon Schlinkert](https://github.com/jonschlinkert)
Released under the MIT license.

***

_This file was generated by [verb](https://github.com/verbose/verb) on January 19, 2016._